@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2016 Red Hat, Inc.
+ * Copyright © 2012 – 2017 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -40,11 +40,6 @@ struct _PhotosTrackerQueue
   gboolean running;
 };
 
-struct _PhotosTrackerQueueClass
-{
-  GObjectClass parent_class;
-};
-
 static void photos_tracker_queue_initable_iface_init (GInitableIface *iface);
 
 
